@@ -15,10 +15,20 @@ sbc <- function(stanmodel, data, M, ..., save_progress, load_incomplete=FALSE) {
   stan_code <- get_stancode(stanmodel)
   stan_code <- scan(what = character(), sep = "\n", quiet = TRUE, text = stan_code)
   pars_lines <- grep("[[:space:]]*(pars_)|(pars_\\[.*\\])[[:space:]]*=", stan_code, value = TRUE)
-  pars_lines <- pars_lines[!grepl("^[[:space:]]*vector", pars_lines) & 
-                           !grepl("^[[:space:]]*real", pars_lines)]   
-  pars_names <- trimws(sapply(strsplit(pars_lines, split = "=", fixed = TRUE), tail, n = 1))
-  pars_names <- unique(sub("^([a-z,A-Z,0-9,_]*)_.*;", "\\1", pars_names))
+  if(length(pars_lines)==1){
+    # if the parameter was defined and assigned in one line:
+    pars_lines <- gsub(".*?=.*?(\\{|\\[)(.*?)(\\]|\\}).*","\\2",pars_lines)
+    pars_names <- trimws(strsplit(pars_lines, split = ",")[[1]])
+    pars_names <- unique(sub("^([a-z,A-Z,0-9,_]*)_.*", "\\1", 
+        pars_names))
+     } else {
+    pars_lines <- pars_lines[!grepl("^[[:space:]]*vector", pars_lines) & 
+        !grepl("^[[:space:]]*real", pars_lines)]
+    pars_names <- trimws(sapply(strsplit(pars_lines, split = "=", 
+        fixed = TRUE), tail, n = 1))
+    pars_names <- unique(sub("^([a-z,A-Z,0-9,_]*)_.*;", "\\1", 
+        pars_names))
+     }
   noUnderscore <- grepl(";", pars_names, fixed=TRUE)
   if (any(noUnderscore)) {
     warning(paste("The following parameters were added to pars_ but did not",
